import { Observable, Subject } from 'rxjs';
import { HttpErrorResponse } from '@angular/common/http';
import { ModelBase } from 'qmuzik-angular-model-core';
import "reflect-metadata";
import { InitialisationService } from './initialisation.service';
import { Instance } from 'qmuzik-angular-model-core';
import { TotalResultCount } from 'qmuzik-angular-model-core';
/**
 * All generated data services for standard components inherits from this base service
 * Contains generic/shared functionality as well as overideable interface methods
 */
export declare class BaseService {
    loggedUser: string;
    defaults: any[];
    defaultsSubscription: Subject<any>;
    autoSelectSubscription: Subject<any>;
    initialisationService: InitialisationService;
    totalResultCount: TotalResultCount;
    constructor();
    /**
     * Standard error handler
     *
     * @param error
     */
    protected handleError(error: HttpErrorResponse): Observable<never>;
    /**
     * Joins result sets from calls to multiple datacontexts into one dataset
     *
     * @param data
     */
    FormatObserveablesArray(data: any[]): ModelBase[];
    /**
     * Perform any formatting required before web API is called upon
     * to save a modelstate
     *
     * @param modelState
     * @param isNew
     */
    FormatBeforeSave(modelState: any, isNew: boolean): any;
    /**
     *  On a new click we may want to initialise
     *      certain properties to a "variable" value
     *      such as:
     *  TodaysDate
     *  NextWorkDate
     *  TomorrowsDate
     *  LoggedInUser
     *  SystemSettings:<PropertyName>
     *  LoggedInUserDivision:<PropertyName>
     *  LoggedInUserCostCenter:<PropertyName>
     *  EndPoint:<PropertyName> e.g."EndPoint:api/ViewCustomerOrdersHeaderCRUDLibrary/GetMySetting", expects a GET, expects single Parameter "PropertyName"
     *
     * @param modelState
     */
    FormatOnNew(modelState: any): any;
    /**
     * Check if any property is a date and editable and convert
     *
     * @param modelState
     */
    FormatBeforeSend(modelState: any): any;
    /**
     * Retrieve the operators of an advanced filter
     *
     * @param filter
     * @param advancedFilter
     */
    GetOperatorArray(filter: any[], advancedFilter: ModelBase[]): any[];
    /**
     * Retrieve the number of rows that will be requested from the service layer
     *
     * @param key
     * @param modelState
     */
    GetNumberOfRows(key: string, modelState: any): number;
    /**
     * Calculate the difference in days between 2 dates
     *
     * @param date1
     * @param date2
     */
    DaysBetween(date1: Date, date2: Date): number;
    DoInstanceActions(modelState: any, isNew: boolean, instance: Instance, isList: boolean): Observable<any>;
    GetDefaultsInstance(instanceId: number, symbolInstanceId: number, CompanyIDPassed: string): Observable<unknown>;
    GetSymbolInstanceSavedObjectCount(instanceInformation: Instance, companyIDPassed: string): Observable<unknown>;
    AddToInstance(modelState: any): Observable<any>;
    DeleteInstanceObjects(instance: Instance, companyID: string): Observable<any>;
    GetPrimaryKeyObject(values: string[], companyID: string, serializationLevel: number): Observable<any>;
    /**
     * Check if an object is of a certain type
     * @param item
     */
    IsType(item: any): boolean;
    GetAutoSelect(instance: Instance, modelState: ModelBase, serializationLevel: number): void;
}
