import { BaseService } from "./base.service";
import { Subject } from "rxjs";
import { ModelStatePropertyAction, View } from "qmuzik-angular-model-core";
import { ComponentRef, ChangeDetectorRef, OnDestroy } from "@angular/core";
import { DynamicViewService } from "./dynamic-view.service";
import { LoginService } from "./login.service";
import { InitialisationService } from "./initialisation.service";
/**
 * Services for the component options component
 */
export declare class ComponentOptionsService extends BaseService implements OnDestroy {
    private dynamicViewService;
    private loginService;
    initialisationService: InitialisationService;
    changeDetectorRef: ChangeDetectorRef;
    modelstateProperties: ModelStatePropertyAction[];
    numericModelStateProperties: ModelStatePropertyAction[];
    sortProperties: ModelStatePropertyAction[];
    aggregateProperties: ModelStatePropertyAction[];
    aggregates: string[];
    aggregateMap: Map<string, string>;
    labels: Map<string, string>;
    modelStatePropertyLabels: Map<string, string>;
    modelStatePropertyLabelsLoading: boolean;
    employeeDefaults: any[];
    changesAppliedtoAllChildren: boolean;
    saveToDefaultTrigger: Subject<unknown>;
    deleteDefaultTrigger: Subject<unknown>;
    sortListTrigger: Subject<unknown>;
    calcAggregateTrigger: Subject<unknown>;
    exportToExcelTrigger: Subject<unknown>;
    undoLastChangeTrigger: Subject<unknown>;
    undoAllChangesTrigger: Subject<unknown>;
    applyChangesToAllChildren: Subject<unknown>;
    serialisationLevelChanged: Subject<unknown>;
    labelsLoaded: Subject<unknown>;
    closeOptionsTrigger: Subject<unknown>;
    pinOptionsTrigger: Subject<unknown>;
    serializationLevel: number;
    views: View[];
    modelStatePropertyLabelsLoaded: boolean;
    private initialisationServiceSubscription;
    constructor(dynamicViewService: DynamicViewService, loginService: LoginService, initialisationService: InitialisationService, changeDetectorRef: ChangeDetectorRef);
    /**
     * Cleanup
     */
    ngOnDestroy(): void;
    setSerialisationLevel(level: number): void;
    /**
     * Extract stuff from component base
     *
     * @param properties
     */
    loadModelStateProperties(properties: ModelStatePropertyAction[]): void;
    loadNumericModelStateProperties(numericProperties: ModelStatePropertyAction[]): void;
    /**
     * Sort
     */
    sortModelStateList(): void;
    /**
     * Aggregate mechanism
     *
     * @param propertyAction
     */
    calculateAggregate(propertyAction: ModelStatePropertyAction): void;
    /**
     * Save to defaults
     *
     * @param defaultName
     */
    saveToDefaults(defaultName: string): void;
    deleteDefault(defaultInstance: any): void;
    setApplyToAll(value: boolean): void;
    getComponentOptionLabel(key: string): string;
    setLabels(labels: Map<string, string>): void;
    exportToExcel(): void;
    undoLastChange(): void;
    undoAllChanges(): void;
    setDefaultLabels(): Promise<void>;
    populateAggregates(): Promise<void>;
    getComponent(viewName: string): Promise<ComponentRef<any>>;
    ViewExists(name: string): boolean;
    GetView(internalName: string): View;
    private loadViews;
    formatString(input: string, ...args: any[]): string;
    simulateResolver(view: View): Promise<boolean>;
    CloseOptions(): void;
    ToggleOptionsPin(): void;
}
