import { OnDestroy } from '@angular/core';
import { BaseService } from './base.service';
import { HttpClient } from '@angular/common/http';
import { Subject, Observable } from 'rxjs';
import { ProcViewActivitiesForInstance, ProcViewVariablesForSymbolInstance, ProcSymbolInstance, InputTask, Instance } from 'qmuzik-angular-model-core';
import { LoginService } from './login.service';
import { Router } from '@angular/router';
import { InitialisationService } from './initialisation.service';
export declare class InstanceService extends BaseService implements OnDestroy {
    private http;
    private loginService;
    private router;
    initialisationService: InitialisationService;
    activitiesSubscription: Subject<{
        "activities": ProcViewActivitiesForInstance[];
        "symbolInstanceId": number;
    }>;
    variableInputOutputSubscription: Subject<{
        "variableInputOutput": ProcViewVariablesForSymbolInstance[];
        "symbolInstanceId": number;
    }>;
    symbolInstanceSubscription: Subject<ProcSymbolInstance>;
    instanceVariableSubscription: Subject<any>;
    updateTaskListSubject: Subject<{
        "Action": string;
        "InputTask": InputTask;
        "SymbolInstanceId": number;
    }>;
    constructor(http: HttpClient, loginService: LoginService, router: Router, initialisationService: InitialisationService);
    ngOnDestroy(): void;
    /**
     * Return all activities for a symbol instance
     * @param symbolInstanceId
     */
    GetActivitiesForInstance(symbolInstanceId: number): void;
    /**
     * Create a new instance and open if found
     * @param symbolInstanceId
     */
    GetNewInstance(templateDefaultAssociationId: any): void;
    /**
     * Check if a qt instance should be opened on login/context switch
     */
    GetOpenOnStartup(): void;
    /**
     * Retrieve the symbol instance object we are working with
     * @param symbolInstanceId
     */
    GetSymbolInstance(symbolInstanceId: number): void;
    /**
     * Return all input output definitions for a symbol instance
     *
     * @param symbolInstanceId
     */
    GetVariableInputOutputForSymbolInstance(symbolInstanceId: number): void;
    /**
     * Return all the instance variables
     *
     * @param instanceId
     */
    GetVariablesForInstance(instanceId: number): void;
    /**
     * Route to the correct view based upon the view name
     *
     * @param viewName
     * @param instanceId
     * @param symbolInstanceId
     * @param instanceMode
     */
    Navigate(viewName: string, instanceId: number, symbolInstanceId: number, instanceMode: boolean): void;
    /**
     * Handle all instance actions when a component does not inherit from componentbase
     *
     * @param modelState
     * @param isNew
     * @param instanceInformation
     */
    DoInstanceActions(modelState: any, isNew: boolean, instanceInformation: Instance): Observable<any>;
    /**
      * Delete/Cancel an instance
      *
      * Effectively, this means setting Active=0
      *
      * Template Type will dicate if all instance history is destroyed.
      *
      * @param instanceId
      * @param symbolInstanceId
      */
    DeleteInstance(instanceId: number, symbolInstanceId: number): void;
}
